### R code from vignette source 'harvestr.Rnw'

###################################################
### code chunk number 1: setup
###################################################
library(harvestr)
library(plyr)
library(lme4)
library(dostats)
print.data.frame <- function(x, ...){
  print(ascii(df, include.rownames = FALSE), type = 'rest')
}


###################################################
### code chunk number 2: ex1-setup
###################################################
library(harvestr)
library(plyr)
seeds <- gather(100, seed=12345)


###################################################
### code chunk number 3: ex1-generate_data
###################################################
datasets <- farm(seeds, {
  x <- rnorm(100)
  y <- rnorm(100, mean=x)
  data.frame(y,x)
})


###################################################
### code chunk number 4: r ex1-analysis
###################################################
analyses <-  harvest(datasets, lm)


###################################################
### code chunk number 5: ex1-summarize
###################################################
library(dostats)
coefs <- t(sapply(analyses, coef))
adply(coefs,2, dostats, mean, sd)


###################################################
### code chunk number 6: stochastic
###################################################
library(lme4)
library(plyr)
fm1 <- lmer(Reaction ~ Days + (1|Subject) + (0+Days|Subject), sleepstudy)
samps <- farm(gather(10), mcmcsamp(fm1, n=1000))
length(samps)
matrices  <- harvest(harvest(samps, as.matrix), as.data.frame)
Days      <- harvest(matrices, `[[`, "Days")
densities <- harvest(Days, density)


###################################################
### code chunk number 7: harvestr.Rnw:125-127
###################################################
plot(densities[[1]])
l_ply(densities, lines)


###################################################
### code chunk number 8: caching_run1
###################################################
unlink("harvestr-cache", recursive=TRUE)  # reset cache
system.time({
  fm1 <- lmer(Reaction ~ Days + (1|Subject) + (0+Days|Subject)
             , sleepstudy)
  samps <- farm(gather(10), mcmcsamp(fm1, n=1000), cache=T)
  matrices  <- harvest(harvest(samps, as.matrix), as.data.frame, cache=T)
})


###################################################
### code chunk number 9: cache_run2
###################################################
system.time({
  fm1 <- lmer(Reaction ~ Days + (1|Subject) + (0+Days|Subject)
             , sleepstudy)
  samps <- farm(gather(10), mcmcsamp(fm1, n=1000), cache=T)
  matrices  <- harvest(harvest(samps, as.matrix), as.data.frame, cache=T)
})


